import sys
import argparse
from pprint import pprint

from pymongo.errors import OperationFailure

from mongopypi.model import client


def project_changelog():
    parser = argparse.ArgumentParser(
        description="Display a project changelog")
    parser.add_argument("name", help="Project name")
    args = parser.parse_args()

    try:
        changelog = client().Changelog.find({'n': args.name})
        for change in changelog:
            print(change)
    except OperationFailure as e:
        sys.exit("Mongo error: %s" % e)
    except KeyboardInterrupt:
        sys.exit("User exit")


def changelog():
    try:
        db = client()

        try:
            last_id = max(db.Synclog.get_sync_id() - 20, 0)
        except IndexError:
            last_id = 0
        while True:
            cursor = db.Synclog.get_tailor_cursor(
                {'_id': {'$gt': last_id}})
            while cursor.alive:
                try:
                    change = cursor.next()
                    last_id = change._id
                    print(change)
                except StopIteration:
                    pass
                except OperationFailure:
                    break
    except KeyboardInterrupt:
        sys.exit("User exit")


def project():
    parser = argparse.ArgumentParser(
        description="Fetch metadata about a project")
    parser.add_argument("name",
                        help="Case sensitive project name")
    args = parser.parse_args()

    try:
        project = client().Project.one({
            'name': args.name,
        })

        if project is None:
            sys.exit(1)

        pprint(project)
    except KeyboardInterrupt:
        sys.exit("User exit")


def release():
    parser = argparse.ArgumentParser(
        description="Fetch metadata about a release")
    parser.add_argument("name",
                        help="Case sensitive project name")
    parser.add_argument("version",
                        help="Project version")
    args = parser.parse_args()

    try:
        release = client().Release.one({
            'name': args.name,
            'version': args.version,
        })

        if release is None:
            sys.exit(1)

        pprint(release)
    except KeyboardInterrupt:
        sys.exit("User exit")
